export default {
    "index": 4,
    "lineNumber": 2,
    "column": 4,
    "message": "Unexpected token **"
};